[−][src]Function websocket_util::stream
pub async fn stream<S, I>(
stream: WebSocketStream<S>
) -> impl Stream<Item = Result<Result<I, JsonError>, WebSocketError>> where
S: AsyncRead + AsyncWrite + Unpin,
I: DeserializeOwned,
Create a stream of higher level primitives out of a client, honoring
and filtering websocket control messages such as Ping and Close.