pub fn subscribe<M, I, St, Si>(
stream: St,
control_channel: Si,
) -> (MessageStream<St, M>, Subscription<Si, M, I>)Expand description
Wrap a stream and an associated control channel into a connected
(MessageStream, Subscription) pair, in which the
subscription can be used to send and receive control messages over
the stream.